@@ -5,10 +5,12 @@ from collections import ChainMap
 from typing import Callable, Any, Union, Mapping, Iterable
 from functools import partial
 import typing
+from warnings import warn
 
 import streamlit as st
 
 from i2 import Sig
+from streamlitfront.app_maker import AppMaker
 from streamlitfront.session_state import get_state, _SessionState
 from streamlitfront.util import func_name, build_element_factory
 
@@ -21,7 +23,7 @@ PageFunc = Callable[[_SessionState], Any]
 PageName = str
 PageSpec = Mapping[PageName, PageFunc]
 App = Callable
-AppMaker = Callable[[Iterable[Callable], Configuration], App]
+# AppMaker = Callable[[Iterable[Callable], Configuration], App]
 
 # ------- configuration/convention/default management -----------------------------------
 
@@ -97,10 +99,26 @@ dflt_hash_funcs = DfltDict(
 def dispatch_funcs(
     funcs: Iterable[Callable], configs: Map = None, convention: Map = dflt_convention,
 ) -> App:
-    """Call this function with target funcs and get an app to run."""
+    """DEPRECATED!
+    Call this function with target funcs and get an app to run."""
+    warn(
+        'This function is deprecated, use "mk_app" instead.',
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    # _get_configs is responsible for merging convention into configs.
+    # The easiest example of that is defaults: convention holding the defaults so
+    # configs doesn't have to express them.
+    # TODO: _get_configs should be expanded (or added as argument of dispatch_func
+    #  so that is can handle more kinds of configs/convention merging.
     configs = _get_configs(configs, convention)
+    # configs holds it's own interpreter: app_maker
     app_maker = configs['app_maker']
+    # ... which needs to be a callable
     assert isinstance(app_maker, Callable)
+    # The app we return the curry of app_maker with funcs and configs bindings.
+    # With that, we should be able to run the app by calling it: app()
+    # Note: We're still open to also specify further configs through app(...) arguments
     return partial(app_maker, funcs=funcs, configs=configs)
 
 
@@ -312,3 +330,139 @@ def pages_app(funcs, configs):
 
     # Mandatory to avoid rollbacks with widgets, must be called at the end of your app
     state.sync()
+
+
+def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
+    """The entrypoint of streamlitfront.
+    Call this function with target objects and get an app to run.
+
+    Example: Render functions
+
+    First define a bunch of functions:
+
+    >>> def foo(a: int = 1, b: int = 2, c=3):
+    ...     return (a * b) + c
+    >>> def bar(x, greeting="hello"):
+    ...     return f"{greeting} {x}"
+    >>> def confuser(a: int, x: float = 3.14):
+    ...     return (a ** 2) * x
+    >>> funcs = [foo, bar, confuser]
+
+    Then make the app from these functions:
+
+    >>> app = mk_app(funcs)
+
+    The default configuration for the application is define by the convention object:
+    ``dflt_convention``. But you can overwrite parts or the entire configuration by
+    setting the ``config`` parameter. The configuration is composed of three parts:
+    app, obj and rendering.
+
+    The app configuration:
+    By default, the application name is "My Front Application", but you can set the
+    title of the application as follow:
+
+    >>> config = {
+    ...     'app': {
+    ...         'title': 'Another application name'
+    ...     }
+    ... }
+    >>> app = mk_app(funcs, config=config)
+
+    The obj configuration:
+    You can define a wrapper to transform the initial object into an output of your
+    choice to be rendered:
+
+    >>> def trans(objs: Iterable):
+    ...     return list(reversed(objs))
+    >>> config = {
+    ...     'obj': {
+    ...         'trans': trans
+    ...     }
+    ... }
+    >>> app = mk_app(funcs, config=config)
+
+    The rendering configuration:
+    You can define the way elements are rendered in the GUI.
+    For instance, you can choose to render a text input instead of a number input for a
+    specific parameter of a specific function:
+
+    >>> from front.elements import COMPONENT_INT_SLIDER
+    >>> config = {
+    ...     'rendering': {
+    ...         'Foo': {
+    ...             'inputs': {
+    ...                 'a': {
+    ...                     'component': COMPONENT_INT_SLIDER,
+    ...                     'max_value': 10
+    ...                 }
+    ...             }
+    ...         }
+    ...     }
+    ... }
+    >>> app = mk_app(funcs, config=config)
+
+    Obviously, you can combine the three types of configuration:
+
+    >>> config = {
+    ...     'app': {
+    ...         'title': 'Another application name'
+    ...     },
+    ...     'obj': {
+    ...         'trans': trans
+    ...     },
+    ...     'rendering': {
+    ...         'Foo': {
+    ...             'inputs': {
+    ...                 'a': {
+    ...                     'component': COMPONENT_INT_SLIDER,
+    ...                     'max_value': 10
+    ...                 }
+    ...             }
+    ...         }
+    ...     }
+    ... }
+    >>> app = mk_app(funcs, config=config)
+
+    You can also overwrite the whole configuration by setting the ``convention``
+    parameter. Be careful though, by overwritting the default convention, you have to
+    make sure that all configuations are defined. Otherwise, the application would
+    crash or behave unexpectedly.
+
+    >>> from front.elements import CONTAINER_VIEW, COMPONENT_FLOAT_SLIDER, COMPONENT_TEXT
+    >>> convention = {
+    ...     'app': {
+    ...         'title': 'Another application name'
+    ...     },
+    ...     'obj': {
+    ...         'trans': trans
+    ...     },
+    ...     'rendering': {
+    ...         Callable: {
+    ...             'container': CONTAINER_VIEW,
+    ...             'inputs': {
+    ...                 float: {
+    ...                     'component': COMPONENT_FLOAT_SLIDER,
+    ...                     'format': '%.2f',
+    ...                     'step': 0.01,
+    ...                 },
+    ...                 Any: {
+    ...                     'component': COMPONENT_TEXT,
+    ...                 },
+    ...             },
+    ...         },
+    ...     },
+    ... }
+    >>> app = mk_app(funcs, convention=convention)
+
+    :param objs: The target objects to render in the streamlit application.
+    :type objs: Iterable
+    :param config: The configuration object for the application. Overwrites the
+    convention for every value present in the configuration object. See above for more
+    details.
+    :type objs: Map
+    :param config: The convention object for the application. Defines the default
+    configuration. See above for more details.
+    :type objs: Map
+    """
+    app_maker = AppMaker()
+    return app_maker.mk_app(objs, config, convention)
